@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2017 Google Inc. All Rights Reserved.
+# Copyright 2017 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,9 @@
 """The gcloud app domain-mappings group."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.calliope import base
 
 
@@ -31,11 +33,9 @@ class DomainMappings(base.Group):
   custom domains, such as `example.com`, instead of the default `appspot.com`
   address. You can use a custom domain with or without SSL.
 
-  App Engine Domain Mappings allow an application to be served via one or many
-  custom domains, such as `example.com`, instead of the default `appspot.com`
-  address. You can use a custom domain with or without SSL. Use the AUTOMATIC
-  management type to automatically provision an SSL certificate for your domain.
-  Use the MANUAL management type to provide your own certificate or omit SSL.
+  Use the AUTOMATIC management type to automatically provision an SSL
+  certificate for your domain. Use the MANUAL management type to provide
+  your own certificate or omit SSL.
   """
 
   detailed_help = {
@@ -47,7 +47,7 @@ class DomainMappings(base.Group):
 
             $ {command} list
 
-          To create a domain with an automatically managed certiticate, run:
+          To create a domain with an automatically managed certificate, run:
 
             $ {command} create 'example.com' --certificate-management=AUTOMATIC
 
