@@ -40,7 +40,7 @@ def _DetailedHelp():
   }
 
 
-def _Args(parser, include_l7_internal_load_balancing):
+def _Args(parser, include_l7_internal_load_balancing, include_log_config):
   """Set up arguments to create an SSL HealthCheck."""
   parser.display_info.AddFormat(flags.DEFAULT_LIST_FORMAT)
   flags.HealthCheckArgument(
@@ -50,9 +50,11 @@ def _Args(parser, include_l7_internal_load_balancing):
       parser, operation_type='create')
   health_checks_utils.AddTcpRelatedCreationArgs(parser)
   health_checks_utils.AddProtocolAgnosticCreationArgs(parser, 'SSL')
+  if include_log_config:
+    health_checks_utils.AddHealthCheckLoggingRelatedArgs(parser)
 
 
-def _Run(args, holder, include_l7_internal_load_balancing):
+def _Run(args, holder, include_l7_internal_load_balancing, include_log_config):
   """Issues the request necessary for adding the health check."""
   client = holder.client
   messages = client.messages
@@ -101,6 +103,10 @@ def _Run(args, holder, include_l7_internal_load_balancing):
         project=health_check_ref.project)
     collection = client.apitools_client.healthChecks
 
+  if include_log_config:
+    request.healthCheck.logConfig = health_checks_utils.CreateLogConfig(
+        client, args)
+
   return client.MakeRequests([(collection, 'Insert', request)])
 
 
@@ -109,18 +115,21 @@ class Create(base.CreateCommand):
   """Create a SSL health check."""
 
   _include_l7_internal_load_balancing = False
+  _include_log_config = False
   detailed_help = _DetailedHelp()
 
   @classmethod
   def Args(cls, parser):
-    _Args(parser, cls._include_l7_internal_load_balancing)
+    _Args(parser, cls._include_l7_internal_load_balancing,
+          cls._include_log_config)
 
   def Run(self, args):
     if self.ReleaseTrack() == base.ReleaseTrack.GA:
       log.warning('The health-checks create ssl command will soon require '
                   'either a --global or --region flag.')
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
-    return _Run(args, holder, self._include_l7_internal_load_balancing)
+    return _Run(args, holder, self._include_l7_internal_load_balancing,
+                self._include_log_config)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.BETA)
@@ -131,4 +140,5 @@ class CreateBeta(Create):
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class CreateAlpha(CreateBeta):
-  pass
+
+  _include_log_config = True
