@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ class HttpsHealthChecks(base.Group):
   """Read and manipulate HTTPS health checks for load balanced instances."""
 
 
-HttpsHealthChecks.category = base.COMPUTE_LOAD_BALANCING_CATEGORY
+HttpsHealthChecks.category = base.LOAD_BALANCING_CATEGORY
 
 HttpsHealthChecks.detailed_help = {
     'brief': ('Read and manipulate HTTPS health checks for load balanced '
