@@ -28,10 +28,12 @@ from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.compute.url_maps import flags
 from googlecloudsdk.command_lib.compute.url_maps import url_maps_utils
+from googlecloudsdk.core import log
 from googlecloudsdk.core import resources
 from googlecloudsdk.core import yaml
 from googlecloudsdk.core.console import console_io
 from googlecloudsdk.core.util import edit
+import six
 
 
 def _DetailedHelp():
@@ -126,7 +128,7 @@ def _EditResource(args, client, holder, original_object, url_map_ref, track):
       break
     except (ValueError, yaml.YAMLParseError, messages.ValidationError,
             exceptions.ToolException) as e:
-      message = getattr(e, 'message', str(e))
+      message = getattr(e, 'message', six.text_type(e))
 
       if isinstance(e, exceptions.ToolException):
         problem_type = 'applying'
@@ -170,12 +172,12 @@ def _BuildFileContents(args, client, modifiable_record, original_record, track):
 def _GetExampleResource(client, track):
   """Gets an example URL Map."""
   backend_service_uri_prefix = (
-      'https://www.googleapis.com/compute/%(track)s/projects/'
+      'https://compute.googleapis.com/compute/%(track)s/projects/'
       'my-project/global/backendServices/' % {
           'track': track
       })
   backend_bucket_uri_prefix = (
-      'https://www.googleapis.com/compute/%(track)s/projects/'
+      'https://compute.googleapis.com/compute/%(track)s/projects/'
       'my-project/global/backendBuckets/' % {
           'track': track
       })
@@ -335,6 +337,9 @@ class Edit(base.Command):
     cls.URL_MAP_ARG.AddArgument(parser)
 
   def Run(self, args):
+    if self.ReleaseTrack() == base.ReleaseTrack.GA:
+      log.warning('The url-maps edit command will soon require '
+                  'either a --global or --region flag.')
     holder = base_classes.ComputeApiHolder(self.ReleaseTrack())
     return _Run(args, holder, self.TRACK, self.URL_MAP_ARG)
 
