@@ -211,7 +211,7 @@ class Update(base.UpdateCommand):
     flags.AddResourceUsageExportFlags(group, is_update=True)
     flags.AddDatabaseEncryptionFlag(group)
     flags.AddDisableDatabaseEncryptionFlag(group)
-    flags.AddVerticalPodAutoscalingFlag(group, hidden=True)
+    flags.AddVerticalPodAutoscalingFlag(group)
     flags.AddAutoprovisioningFlags(group)
 
   def ParseUpdateOptions(self, args, locations):
@@ -503,6 +503,7 @@ class UpdateBeta(Update):
     flags.AddEnableShieldedNodesFlags(group)
     flags.AddDatabaseEncryptionFlag(group)
     flags.AddDisableDatabaseEncryptionFlag(group)
+    flags.AddReleaseChannelFlag(group, is_update=True)
 
   def ParseUpdateOptions(self, args, locations):
     opts = container_command_util.ParseUpdateOptionsBase(args, locations)
@@ -516,6 +517,7 @@ class UpdateBeta(Update):
     opts.enable_resource_consumption_metering = args.enable_resource_consumption_metering
     flags.ValidateIstioConfigUpdateArgs(args.istio_config, args.disable_addons)
     opts.enable_stackdriver_kubernetes = args.enable_stackdriver_kubernetes
+    opts.release_channel = args.release_channel
 
     # Top-level update options are automatically forced to be
     # mutually-exclusive, so we don't need special handling for these two.
@@ -573,6 +575,7 @@ class UpdateAlpha(Update):
     flags.AddDatabaseEncryptionFlag(group)
     flags.AddDisableDatabaseEncryptionFlag(group)
     flags.AddCostManagementConfigFlag(group, is_update=True)
+    flags.AddReleaseChannelFlag(group, is_update=True)
 
   def ParseUpdateOptions(self, args, locations):
     opts = container_command_util.ParseUpdateOptionsBase(args, locations)
@@ -589,6 +592,7 @@ class UpdateAlpha(Update):
     flags.ValidateIstioConfigUpdateArgs(args.istio_config, args.disable_addons)
     opts.enable_peering_route_sharing = args.enable_peering_route_sharing
     opts.enable_stackdriver_kubernetes = args.enable_stackdriver_kubernetes
+    opts.release_channel = args.release_channel
 
     # Top-level update options are automatically forced to be
     # mutually-exclusive, so we don't need special handling for these two.
