@@ -27,16 +27,35 @@ from googlecloudsdk.command_lib.util.args import labels_util
 from googlecloudsdk.core import log
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.GA)
 class Update(base.UpdateCommand):
-  """This feature is part of an invite-only release of the Cloud Pub/Sub API.
+  """Updates an existing Cloud Pub/Sub topic."""
 
-  Updates an existing Cloud Pub/Sub topic.
-  This feature is part of an invitation-only release of the underlying
-  Cloud Pub/Sub API. The command will generate errors unless you have access to
-  this API. This restriction should be relaxed in the near future. Please
-  contact cloud-pubsub@google.com with any questions in the meantime.
-  """
+  detailed_help = {
+      'EXAMPLES':
+          """\
+          To update existing labels on a Cloud Pub/Sub topic, run:
+
+              $ {command} mytopic --update-labels=KEY1=VAL1,KEY2=VAL2
+
+          To clear all labels on a Cloud Pub/Sub topic, run:
+
+              $ {command} mytopic --clear-labels
+
+          To remove an existing label on a Cloud Pub/Sub topic, run:
+
+              $ {command} mytopic --remove-labels=KEY1,KEY2
+
+          To update a Cloud Pub/Sub topic's message storage policy, run:
+
+              $ {command} mytopic --message-storage-policy-allowed-regions=some-cloud-region1,some-cloud-region2
+
+          To recompute a Cloud Pub/Sub topic's message storage policy based on your organization's "Resource Location Restriction" policy, run:
+
+              $ {command} mytopic --recompute-message-storage-policy
+          """
+  }
 
   @staticmethod
   def Args(parser):
@@ -82,11 +101,9 @@ class Update(base.UpdateCommand):
 
     result = None
     try:
-      result = client.Patch(
-          topic_ref,
-          labels_update.GetOrNone(),
-          args.recompute_message_storage_policy,
-          args.message_storage_policy_allowed_regions)
+      result = client.Patch(topic_ref, labels_update.GetOrNone(),
+                            args.recompute_message_storage_policy,
+                            args.message_storage_policy_allowed_regions)
     except topics.NoFieldsSpecifiedError:
       operations = [
           'clear_labels', 'update_labels', 'remove_labels',
