@@ -49,17 +49,6 @@ class Create(base.Command):
 
   @staticmethod
   def CommonArgs(parser):
-    # Flags specific to managed CR
-    managed_group = flags.GetManagedArgGroup(parser)
-    flags.AddRegionArg(managed_group)
-    # Flags specific to CRoGKE
-    gke_group = flags.GetGkeArgGroup(parser)
-    concept_parsers.ConceptParser([resource_args.CLUSTER_PRESENTATION
-                                  ]).AddToParser(gke_group)
-    # Flags specific to connecting to a Kubernetes cluster (kubeconfig)
-    kubernetes_group = flags.GetKubernetesArgGroup(parser)
-    flags.AddKubeconfigFlags(kubernetes_group)
-    # Flags not specific to any platform
     parser.add_argument(
         '--service', required=True,
         help='Create domain mapping for the given service.')
@@ -71,7 +60,7 @@ class Create(base.Command):
         prefixes=False)
     concept_parsers.ConceptParser([
         domain_mapping_presentation]).AddToParser(parser)
-    flags.AddPlatformArg(parser)
+
     parser.display_info.AddFormat(
         """table(
         name:label=NAME,
