@@ -30,7 +30,7 @@ from googlecloudsdk.command_lib.util.concepts import presentation_specs
 from googlecloudsdk.core import log
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
 class List(commands.List):
   """List available revisions."""
 
@@ -41,22 +41,12 @@ class List(commands.List):
       'EXAMPLES': """\
           To list all revisions for the provided service:
 
-              $ {command} --service foo
+              $ {command} --service=foo
          """,
   }
 
   @classmethod
   def CommonArgs(cls, parser):
-    # Flags specific to managed CR
-    managed_group = flags.GetManagedArgGroup(parser)
-    flags.AddRegionArgWithDefault(managed_group)
-    # Flags specific to CRoGKE
-    gke_group = flags.GetGkeArgGroup(parser)
-    concept_parsers.ConceptParser(
-        [resource_args.CLUSTER_PRESENTATION]).AddToParser(gke_group)
-    # Flags specific to connecting to a Kubernetes cluster (kubeconfig)
-    kubernetes_group = flags.GetKubernetesArgGroup(parser)
-    flags.AddKubeconfigFlags(kubernetes_group)
     # Flags specific to connecting to a cluster
     cluster_group = flags.GetClusterArgGroup(parser)
     namespace_presentation = presentation_specs.ResourcePresentationSpec(
@@ -67,9 +57,10 @@ class List(commands.List):
         prefixes=False)
     concept_parsers.ConceptParser(
         [namespace_presentation]).AddToParser(cluster_group)
+
     # Flags not specific to any platform
     flags.AddServiceFlag(parser)
-    flags.AddPlatformArg(parser)
+
     parser.display_info.AddFormat(
         'table('
         '{ready_column},'
