@@ -59,18 +59,6 @@ class Replace(base.Command):
 
   @staticmethod
   def Args(parser):
-    # Flags specific to managed CR
-    managed_group = flags.GetManagedArgGroup(parser)
-    flags.AddRegionArg(managed_group)
-
-    # Flags specific to CRoGKE
-    gke_group = flags.GetGkeArgGroup(parser)
-    concept_parsers.ConceptParser([resource_args.CLUSTER_PRESENTATION
-                                  ]).AddToParser(gke_group)
-
-    # Flags specific to connecting to a Kubernetes cluster (kubeconfig)
-    kubernetes_group = flags.GetKubernetesArgGroup(parser)
-    flags.AddKubeconfigFlags(kubernetes_group)
 
     # Flags specific to connecting to a cluster
     cluster_group = flags.GetClusterArgGroup(parser)
@@ -85,7 +73,6 @@ class Replace(base.Command):
 
     # Flags not specific to any platform
     flags.AddAsyncFlag(parser)
-    flags.AddPlatformArg(parser)
     parser.add_argument(
         'FILE',
         action='store',
